diff --git a/src/backend/executor/nodeLimit.c b/src/backend/executor/nodeLimit.c
index c503512588..159542b81e 100644
--- a/src/backend/executor/nodeLimit.c
+++ b/src/backend/executor/nodeLimit.c
@@ -130,7 +130,7 @@ ExecLimit(PlanState *pstate)
 			}
 
 			/*
-			 * We may needed this tuple in backward scan so put it into
+			 * We may need this tuple in backward scan so put it into
 			 * tuplestore.
 			 */
 			if (node->limitOption == PERCENTAGE)
@@ -219,7 +219,7 @@ ExecLimit(PlanState *pstate)
 				}
 
 				/*
-				 * When in percentage mode, we need to see if we can get any
+				 * When in PERCENTAGE mode, we need to see if we can get any
 				 * additional rows from the subplan (enough to increase the
 				 * node->count value).
 				 */
@@ -369,7 +369,7 @@ ExecLimit(PlanState *pstate)
 					elog(ERROR, "LIMIT subplan failed to run backwards");
 				node->subSlot = slot;
 				node->lstate = LIMIT_INWINDOW;
-				/* position does not change 'cause we didn't advance it before */
+				/* position does not change because we didn't advance it before */
 			}
 			break;
 
@@ -505,7 +505,7 @@ recompute_limits(LimitState *node)
 	 * Notify child node about limit.  Note: think not to "optimize" by
 	 * skipping ExecSetTupleBound if compute_tuples_needed returns < 0.  We
 	 * must update the child node anyway, in case this is a rescan and the
-	 * previous time we got a different result. In PERCENTAGE option there are
+	 * previous time we got a different result. In PERCENTAGE option there is
 	 * no bound on the number of output tuples
 	 */
 	if (node->limitOption != PERCENTAGE)
diff --git a/src/backend/optimizer/plan/planner.c b/src/backend/optimizer/plan/planner.c
index 407b61787d..702179e576 100644
--- a/src/backend/optimizer/plan/planner.c
+++ b/src/backend/optimizer/plan/planner.c
@@ -2249,7 +2249,7 @@ grouping_planner(PlannerInfo *root, bool inheritance_update,
 	{
 
 		/*
-		 * In PERCENTAGE option there are no bound on the number of output
+		 * In PERCENTAGE option there is no bound on the number of output
 		 * tuples
 		 */
 		if (parse->limitOption == PERCENTAGE)
diff --git a/src/include/nodes/parsenodes.h b/src/include/nodes/parsenodes.h
index b158e9eaeb..b49ce10a31 100644
--- a/src/include/nodes/parsenodes.h
+++ b/src/include/nodes/parsenodes.h
@@ -159,7 +159,7 @@ typedef struct Query
 
 	Node	   *limitOffset;	/* # of result tuples to skip (int8 expr) */
 	Node	   *limitCount;		/* # of result tuples to return (int8 expr) */
-	LimitOption limitOption;	/* limit type */
+	LimitOption limitOption;	/* LIMIT in percentage or exact number */
 
 	List	   *rowMarks;		/* a list of RowMarkClause's */
 
@@ -1596,7 +1596,7 @@ typedef struct SelectStmt
 	List	   *sortClause;		/* sort clause (a list of SortBy's) */
 	Node	   *limitOffset;	/* # of result tuples to skip */
 	Node	   *limitCount;		/* # of result tuples to return */
-	LimitOption limitOption;	/* limit type */
+	LimitOption limitOption;	/* LIMIT in percentage or exact number */
 	List	   *lockingClause;	/* FOR UPDATE (list of LockingClause's) */
 	WithClause *withClause;		/* WITH clause */
 
diff --git a/src/include/nodes/pathnodes.h b/src/include/nodes/pathnodes.h
index 21ff6a9c4c..c6195e4dd6 100644
--- a/src/include/nodes/pathnodes.h
+++ b/src/include/nodes/pathnodes.h
@@ -1795,7 +1795,7 @@ typedef struct LimitPath
 	Path	   *subpath;		/* path representing input source */
 	Node	   *limitOffset;	/* OFFSET parameter, or NULL if none */
 	Node	   *limitCount;		/* COUNT parameter, or NULL if none */
-	LimitOption limitOption;	/* LIMIT in percentage or  exact number */
+	LimitOption limitOption;	/* LIMIT in percentage or exact number */
 } LimitPath;
 
 
diff --git a/src/include/nodes/plannodes.h b/src/include/nodes/plannodes.h
index c8c497295b..03f56ea247 100644
--- a/src/include/nodes/plannodes.h
+++ b/src/include/nodes/plannodes.h
@@ -967,7 +967,7 @@ typedef struct Limit
 	Plan		plan;
 	Node	   *limitOffset;	/* OFFSET parameter, or NULL if none */
 	Node	   *limitCount;		/* COUNT parameter, or NULL if none */
-	LimitOption limitOption;	/* LIMIT in percentage or  exact number */
+	LimitOption limitOption;	/* LIMIT in percentage or exact number */
 } Limit;
 
 
